@@ -101,7 +101,7 @@ class ComboKV(Combo):
     
     @options.setter
     def options(self, options):
-        if type(options[0])!=tuple:
+        if not options or type(options[0])!=tuple:
             self._KV = False
         else:
             self._KV = True
